@@ -1,9 +1,9 @@
 DATA = {
   "Examples": [], 
-  "dist": "python-fileinspector-1.0.1-py_0", 
+  "dist": "python-fileinspector-1.0.2-py_0", 
   "python-scripts": [], 
   "site-packages": [
-    "python_fileinspector-1.0.1-py2.7.egg", 
+    "python_fileinspector-1.0.2-py3.6.egg", 
     "python_fileinspector.pth"
   ]
 }
@@ -15,9 +15,10 @@ conda_build/noarch_python.py.
 
 """
 import os
+from os.path import dirname, exists, isdir, join, normpath
 import sys
 import shutil
-from os.path import dirname, exists, isdir, join, normpath
+
 
 # Silence pyflakes. This variable is added when link.py is written by
 # conda_build.noarch_python.
@@ -80,11 +81,11 @@ def create_script(fn):
     src = join(THIS_DIR, 'python-scripts', fn)
     dst = join(BIN_DIR, fn)
     if sys.platform == 'win32':
-        shutil.copyfile(src, dst + '-script.py')
+        shutil.copy2(src, dst + '-script.py')
         FILES.append('Scripts/%s-script.py' % fn)
-        shutil.copyfile(join(THIS_DIR,
-                             'cli-%d.exe' % (8 * tuple.__itemsize__)),
-                        dst + '.exe')
+        shutil.copy2(join(THIS_DIR,
+                          'cli-%d.exe' % (8 * tuple.__itemsize__)),
+                     dst + '.exe')
         FILES.append('Scripts/%s.exe' % fn)
     else:
         with open(src) as fi:
@@ -92,7 +93,7 @@ def create_script(fn):
         with open(dst, 'w') as fo:
             fo.write('#!%s\n' % normpath(sys.executable))
             fo.write(data)
-        os.chmod(dst, 0o755)
+        os.chmod(dst, 0o775)
         FILES.append('bin/%s' % fn)
 
 
